# Geospatial API

This contains utilities, blockers, and comparers relevant to geospatial data.


## Coordinates

::: mismo.lib.geo.CoordinateBlocker
::: mismo.lib.geo.distance_km

## Addresses

::: mismo.lib.geo.us_census_geocode
::: mismo.lib.geo.AddressesDimension
::: mismo.lib.geo.AddressesMatchLevel
::: mismo.lib.geo.match_level
::: mismo.lib.geo.postal_parse_address
::: mismo.lib.geo.postal_fingerprint_address
::: mismo.lib.geo.spacy_tag_address
